@@ -1,3 +1,4 @@
+using Arrow
 using Base.Iterators: product
 using Dates
 using Documenter: doctest
@@ -20,12 +21,11 @@ include("test_utils.jl")
     include("anchoredinterval.jl")
     include("comparisons.jl")
     include("sets.jl")
+    include("arrow.jl")
     include("plotting.jl")
 
-    # Note: The output of the doctests currently requires a newer version of Julia
-    # https://github.com/JuliaLang/julia/pull/34387
-    # The doctests fail on x86, so only run them on 64-bit hardware
-    if v"1.6" <= VERSION < v"1.7" && Sys.WORD_SIZE == 64
+    # only run doctests on one version (LTS)
+    if v"1.10" <= VERSION < v"1.11"
         doctest(Intervals)
     else
         @warn "Skipping doctests"
